@@ -1,3 +1,3 @@
-from .table import Table
+from .table import Table, create_table
 from .columns import Col, BoolCol, DateCol, DatetimeCol, LinkCol, ButtonCol,\
     OptCol
