@@ -31,19 +31,24 @@ class Table(with_metaclass(TableMeta)):
     table. Initialise with an iterable of objects. Then either use the
     __html__ method, or just output in a template to output the table
     as html. Can also set a list of classes, either when declaring the
-    table, or when initialising.
+    table, or when initialising. Can also set the text to display if
+    there are no items to display.
 
     """
 
     classes = []
     allow_sort = False
+    no_items = 'No Items'
 
-    def __init__(self, items, classes=None, sort_by=None, sort_reverse=False):
+    def __init__(self, items, classes=None, sort_by=None,
+                 sort_reverse=False, no_items=None):
         self.items = items
         self.sort_by = sort_by
         self.sort_reverse = sort_reverse
         if classes is not None:
             self.classes = classes
+        if no_items is not None:
+            self.no_items = no_items
 
     def classes_html_attr(self):
         if not self.classes:
@@ -59,26 +64,33 @@ class Table(with_metaclass(TableMeta)):
                 thead=self.thead(),
                 tbody=tbody)
         else:
-            return '<p>No Items</p>'
+            return '<p>{}</p>'.format(self.no_items)
 
     def thead(self):
         return '<thead><tr>{}</tr></thead>'.format(''.join(
-            (self.th(col_key, col) for col_key, col in self._cols.items())))
+            (self.th(col_key, col) for col_key, col in self._cols.items()
+             if col.show)))
 
     def tbody(self):
-        out = []
-        for i in self.items:
-            out.append(self.tr(i))
+        out = [self.tr(item) for item in self.items]
         if out:
             return '<tbody>\n{}\n</tbody>'.format('\n'.join(out))
         else:
             return ''
 
-    def tr(self, i):
-        out = []
-        for attr, c in self._cols.items():
-            out.append(c.td(i, attr))
-        return '<tr>{}</tr>'.format(''.join(out))
+    def tr_format(self, item):
+        """Returns the string that is formatted with the contents of the
+        tr. Override this if you want to alter the attributes of the
+        tr.
+
+        """
+
+        return '<tr>{}</tr>'
+
+    def tr(self, item):
+        return self.tr_format(item).format(
+            ''.join(c.td(item, attr) for attr, c in self._cols.items()
+                    if c.show))
 
     def th_contents(self, col_key, col):
         escaped = Markup.escape(col.name)
